<?php

global $loginbox_text;
$loginbox_text = array (

'username'      =>  'Benutzername',
'password'      =>  'Passwort',
'login'         =>  'Login',

// Added in 0.9.6
'rememberme'    =>  'Bei jedem Besuch automatisch einloggen', 

// Added in 0.9.7
'lostpassword'  =>  'Passwort vergessen?',

);
?>
